@@ -57,7 +57,7 @@
 /* #undef HAVE_HALIDE */
 
 /* Vulkan support */
-/* #undef HAVE_VULKAN */
+#define HAVE_VULKAN
 
 /* Define to 1 if you have the <inttypes.h> header file. */
 /* #undef HAVE_INTTYPES_H */
@@ -73,7 +73,7 @@
 /* #undef HAVE_JASPER */
 
 /* AVIF codec */
-#define HAVE_AVIF
+/* #undef HAVE_AVIF */
 
 /* IJG JPEG codec */
 #define HAVE_JPEG
@@ -104,7 +104,7 @@
 #define HAVE_OPENEXR
 
 /* OpenGL support*/
-#define HAVE_OPENGL
+/* #undef HAVE_OPENGL */
 
 /* PNG codec */
 #define HAVE_PNG
@@ -138,7 +138,7 @@
 #define HAVE_VA_INTEL
 
 /* Lapack */
-/* #undef HAVE_LAPACK */
+#define HAVE_LAPACK
 
 /* Library was compiled with functions instrumentation */
 /* #undef ENABLE_INSTRUMENTATION */
